# -*- coding: utf-8 -*-
# @Author  : LG

from PyQt5 import QtGui, QtCore, QtWidgets
from ISAT.ui.shortcut_dialog import Ui_Dialog
import functools

class ShortcutDialog(QtWidgets.QDialog, Ui_Dialog):
    def __init__(self, parent, mainwindow):
        super(ShortcutDialog, self).__init__(parent)
        self.mainwindow = mainwindow
        self.setupUi(self)
        self.setWindowModality(QtCore.Qt.WindowModality.WindowModal)

        self.pushButton_reset.clicked.connect(self.reset_shortcut)
        self.pushButton_close.clicked.connect(self.close)

        self.columns = 3    # action列数
        self.column_columns = 3 # 每个action有多少列内容[icon, label, QKeySequenceEdit]

        # 可以自定义快捷键的action列表
        self.actions_list = [
            self.mainwindow.actionImages_dir,
            self.mainwindow.actionLabel_dir,
            self.mainwindow.actionPrev_image,
            self.mainwindow.actionNext_image,
            self.mainwindow.actionSetting,
            self.mainwindow.actionExit,

            self.mainwindow.actionSegment_anything_point,
            self.mainwindow.actionSegment_anything_box,
            self.mainwindow.actionPolygon,
            self.mainwindow.actionRepaint,
            self.mainwindow.actionVideo_segment,
            self.mainwindow.actionVideo_segment_once,
            self.mainwindow.actionVideo_segment_five_times,
            self.mainwindow.actionBackspace,
            self.mainwindow.actionFinish,
            self.mainwindow.actionCancel,
            self.mainwindow.actionEdit,
            self.mainwindow.actionDelete,
            self.mainwindow.actionSave,
            self.mainwindow.actionCopy,
            self.mainwindow.actionTo_top,
            self.mainwindow.actionTo_bottom,
            self.mainwindow.actionUnion,
            self.mainwindow.actionSubtract,
            self.mainwindow.actionIntersect,
            self.mainwindow.actionExclude,

            self.mainwindow.actionPrev_group,
            self.mainwindow.actionNext_group,
            self.mainwindow.actionVisible,
            self.mainwindow.actionBit_map,
            self.mainwindow.actionZoom_in,
            self.mainwindow.actionZoom_out,
            self.mainwindow.actionFit_window,
            self.mainwindow.actionScene_shot,
            self.mainwindow.actionWindow_shot,

            # self.mainwindow.actionModel_manage,

            # self.mainwindow.actionConverter,
            # self.mainwindow.actionVideo_to_frames,
            # self.mainwindow.actionAuto_segment_with_bounding_box,
            # self.mainwindow.actionAnno_validator,

            self.mainwindow.actionLanguage,
            # self.mainwindow.actionShortcut,
            # self.mainwindow.actionAbout,
        ]
        self.update_ui()

    def update_ui(self):
        for i in range(self.gridLayout.count()):
            self.gridLayout.itemAt(i).widget().deleteLater()

        for index, action in enumerate(self.actions_list):
            icon = QtWidgets.QLabel()
            icon.setFixedSize(30, 30)
            icon.setPixmap(QtGui.QPixmap(action.icon().pixmap(QtCore.QSize(24, 24))))
            label = QtWidgets.QLabel()
            label.setText(action.text())
            key_edit = QtWidgets.QKeySequenceEdit()
            key_edit.setFocusPolicy(QtCore.Qt.FocusPolicy.ClickFocus)
            key_edit.setFixedSize(150, 30)
            key_edit.setKeySequence(action.shortcut())
            key_edit.editingFinished.connect(functools.partial(self.shortcut_change_finish, action))

            self.gridLayout.addWidget(icon, index// self.columns, index % self.columns * self.column_columns, 1, 1)
            self.gridLayout.addWidget(label, index// self.columns, index % self.columns * self.column_columns + 1, 1, 1)
            self.gridLayout.addWidget(key_edit, index// self.columns, index % self.columns * self.column_columns + 2, 1, 1)

    def reset_shortcut(self):
        self.mainwindow.load_actions_shortcut(default=True)
        self.update_ui()

    def shortcut_change_finish(self, action):
        ks = self.sender().keySequence()

        if ks.toString() in ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']:
            self.sender().setKeySequence(action.shortcut())
        else:
            if ks.toString() == 'Backspace':
                ks = QtGui.QKeySequence(0)

            action.setShortcut(ks)  # 设置快捷键
            self.sender().setKeySequence(action.shortcut()) # 同步显示
            print("New shortcut [{}] for {}".format(ks.toString(), action.text()))

            for action_str in self.mainwindow.cfg['shortcut']:
                try:
                    if eval('self.mainwindow.' + action_str) == action:
                        self.mainwindow.cfg['shortcut'][action_str]['key'] = ks.toString()
                        break
                except Exception:pass

            self.sender().clearFocus()

            self.mainwindow.save_software_cfg()





# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.

# This source code is licensed under the license found in the
# LICENSE file in the root directory of this source tree.

import logging
import os

import torch
from hydra import compose
from hydra.utils import instantiate
from omegaconf import OmegaConf

from .. import sam2

# Check if the user is running Python from the parent directory of the sam2 repo
# (i.e. the directory where this repo is cloned into) -- this is not supported since
# it could shadow the sam2 package and cause issues.
if os.path.isdir(os.path.join(sam2.__path__[0], "sam2")):
    # If the user has "sam2/sam2" in their path, they are likey importing the repo itself
    # as "sam2" rather than importing the "sam2" python package (i.e. "sam2/sam2" directory).
    # This typically happens because the user is running Python from the parent directory
    # that contains the sam2 repo they cloned.
    raise RuntimeError(
        "You're likely running Python from the parent directory of the sam2 repository "
        "(i.e. the directory where https://github.com/facebookresearch/sam2 is cloned into). "
        "This is not supported since the `sam2` Python package could be shadowed by the "
        "repository name (the repository is also named `sam2` and contains the Python package "
        "in `sam2/sam2`). Please run Python from another directory (e.g. from the repo dir "
        "rather than its parent dir, or from your home directory) after installing SAM 2."
    )


HF_MODEL_ID_TO_FILENAMES = {
    "facebook/sam2-hiera-tiny": (
        "configs/sam2/sam2_hiera_t.yaml",
        "sam2_hiera_tiny.pt",
    ),
    "facebook/sam2-hiera-small": (
        "configs/sam2/sam2_hiera_s.yaml",
        "sam2_hiera_small.pt",
    ),
    "facebook/sam2-hiera-base-plus": (
        "configs/sam2/sam2_hiera_b+.yaml",
        "sam2_hiera_base_plus.pt",
    ),
    "facebook/sam2-hiera-large": (
        "configs/sam2/sam2_hiera_l.yaml",
        "sam2_hiera_large.pt",
    ),
    "facebook/sam2.1-hiera-tiny": (
        "configs/sam2.1/sam2.1_hiera_t.yaml",
        "sam2.1_hiera_tiny.pt",
    ),
    "facebook/sam2.1-hiera-small": (
        "configs/sam2.1/sam2.1_hiera_s.yaml",
        "sam2.1_hiera_small.pt",
    ),
    "facebook/sam2.1-hiera-base-plus": (
        "configs/sam2.1/sam2.1_hiera_b+.yaml",
        "sam2.1_hiera_base_plus.pt",
    ),
    "facebook/sam2.1-hiera-large": (
        "configs/sam2.1/sam2.1_hiera_l.yaml",
        "sam2.1_hiera_large.pt",
    ),
}


def build_sam2(
    config_file,
    ckpt_path=None,
    device="cuda",
    mode="eval",
    hydra_overrides_extra=[],
    apply_postprocessing=True,
    **kwargs,
):

    if apply_postprocessing:
        hydra_overrides_extra = hydra_overrides_extra.copy()
        hydra_overrides_extra += [
            # dynamically fall back to multi-mask if the single mask is not stable
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_via_stability=true",
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_stability_delta=0.05",
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_stability_thresh=0.98",
        ]
    # Read config and init model
    print('config_file: ' , config_file)
    cfg = compose(config_name=config_file, overrides=hydra_overrides_extra)
    OmegaConf.resolve(cfg)
    model = instantiate(cfg.model, _recursive_=True)
    _load_checkpoint(model, ckpt_path)
    model = model.to(device)
    if mode == "eval":
        model.eval()
    return model


def build_sam2_video_predictor(
    config_file,
    ckpt_path=None,
    device="cuda",
    mode="eval",
    hydra_overrides_extra=[],
    apply_postprocessing=True,
    **kwargs,
):
    hydra_overrides = [
        "++model._target_=ISAT.segment_any.sam2.sam2_video_predictor.SAM2VideoPredictor",
    ]
    if apply_postprocessing:
        hydra_overrides_extra = hydra_overrides_extra.copy()
        hydra_overrides_extra += [
            # dynamically fall back to multi-mask if the single mask is not stable
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_via_stability=true",
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_stability_delta=0.05",
            "++model.sam_mask_decoder_extra_args.dynamic_multimask_stability_thresh=0.98",
            # the sigmoid mask logits on interacted frames with clicks in the memory encoder so that the encoded masks are exactly as what users see from clicking
            "++model.binarize_mask_from_pts_for_mem_enc=true",
            # fill small holes in the low-res masks up to `fill_hole_area` (before resizing them to the original video resolution)
            "++model.fill_hole_area=8",
        ]
    hydra_overrides.extend(hydra_overrides_extra)

    # Read config and init model
    cfg = compose(config_name=config_file, overrides=hydra_overrides)
    OmegaConf.resolve(cfg)
    model = instantiate(cfg.model, _recursive_=True)
    _load_checkpoint(model, ckpt_path)
    model = model.to(device)
    if mode == "eval":
        model.eval()
    return model


def _hf_download(model_id):
    from huggingface_hub import hf_hub_download

    config_name, checkpoint_name = HF_MODEL_ID_TO_FILENAMES[model_id]
    ckpt_path = hf_hub_download(repo_id=model_id, filename=checkpoint_name)
    return config_name, ckpt_path


def build_sam2_hf(model_id, **kwargs):
    config_name, ckpt_path = _hf_download(model_id)
    return build_sam2(config_file=config_name, ckpt_path=ckpt_path, **kwargs)


def build_sam2_video_predictor_hf(model_id, **kwargs):
    config_name, ckpt_path = _hf_download(model_id)
    return build_sam2_video_predictor(
        config_file=config_name, ckpt_path=ckpt_path, **kwargs
    )


def _load_checkpoint(model, ckpt_path):
    if ckpt_path is not None:
        sd = torch.load(ckpt_path, map_location="cpu", weights_only=False)["model"]
        missing_keys, unexpected_keys = model.load_state_dict(sd)
        if missing_keys:
            logging.error(missing_keys)
            raise RuntimeError()
        if unexpected_keys:
            logging.error(unexpected_keys)
            raise RuntimeError()
        logging.info("Loaded checkpoint sucessfully")


def build_sam2_hiera_tiny(checkpoint=None):
    return build_sam2('sam2_hiera_t.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_small(checkpoint=None):
    return build_sam2('sam2_hiera_s.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_base_plus(checkpoint=None):
    return build_sam2('sam2_hiera_b+.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_large(checkpoint=None):
    return build_sam2('sam2_hiera_l.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_tiny_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2_hiera_t.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_small_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2_hiera_s.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_base_plus_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2_hiera_b+.yaml', ckpt_path=checkpoint)


def build_sam2_hiera_large_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2_hiera_l.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_tiny(checkpoint=None):
    return build_sam2('sam2.1_hiera_t.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_small(checkpoint=None):
    return build_sam2('sam2.1_hiera_s.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_base_plus(checkpoint=None):
    return build_sam2('sam2.1_hiera_b+.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_large(checkpoint=None):
    return build_sam2('sam2.1_hiera_l.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_tiny_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2.1_hiera_t.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_small_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2.1_hiera_s.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_base_plus_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2.1_hiera_b+.yaml', ckpt_path=checkpoint)


def build_sam21_hiera_large_video_predictor(checkpoint=None):
    return build_sam2_video_predictor('sam2.1_hiera_l.yaml', ckpt_path=checkpoint)


sam_model_registry = {
    # sam2
    "sam2_hiera_tiny": build_sam2_hiera_tiny,
    "sam2_hiera_small": build_sam2_hiera_small,
    "sam2_hiera_base_plus": build_sam2_hiera_base_plus,
    "sam2_hiera_large": build_sam2_hiera_large,

    "sam2_hiera_tiny_video": build_sam2_hiera_tiny_video_predictor,
    "sam2_hiera_small_video": build_sam2_hiera_small_video_predictor,
    "sam2_hiera_base_plus_video": build_sam2_hiera_base_plus_video_predictor,
    "sam2_hiera_large_video": build_sam2_hiera_large_video_predictor,

    # sam2.1
    "sam2.1_hiera_tiny": build_sam21_hiera_tiny,
    "sam2.1_hiera_small": build_sam21_hiera_small,
    "sam2.1_hiera_base_plus": build_sam21_hiera_base_plus,
    "sam2.1_hiera_large": build_sam21_hiera_large,

    "sam2.1_hiera_tiny_video": build_sam21_hiera_tiny_video_predictor,
    "sam2.1_hiera_small_video": build_sam21_hiera_small_video_predictor,
    "sam2.1_hiera_base_plus_video": build_sam21_hiera_base_plus_video_predictor,
    "sam2.1_hiera_large_video": build_sam21_hiera_large_video_predictor,
}



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/media/lg/disk2/PycharmProjects/ISAT_with_segment_anything/ISAT/ui/shortcut_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1280, 720)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(600, 300))
        Dialog.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        Dialog.setFont(font)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setContentsMargins(9, 9, 9, 9)
        self.verticalLayout.setObjectName("verticalLayout")
        self.widget = QtWidgets.QWidget(Dialog)
        self.widget.setMinimumSize(QtCore.QSize(0, 60))
        self.widget.setMaximumSize(QtCore.QSize(16777215, 60))
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.widget)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(20)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        font.setKerning(True)
        self.label.setFont(font)
        self.label.setTextFormat(QtCore.Qt.AutoText)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.verticalLayout.addWidget(self.widget)
        self.widget_2 = QtWidgets.QWidget(Dialog)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setKerning(True)
        self.widget_2.setFont(font)
        self.widget_2.setObjectName("widget_2")
        self.gridLayout = QtWidgets.QGridLayout(self.widget_2)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout.addWidget(self.widget_2)
        self.widget_3 = QtWidgets.QWidget(Dialog)
        self.widget_3.setMaximumSize(QtCore.QSize(16777215, 30))
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(1105, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.pushButton_reset = QtWidgets.QPushButton(self.widget_3)
        self.pushButton_reset.setMinimumSize(QtCore.QSize(80, 30))
        self.pushButton_reset.setMaximumSize(QtCore.QSize(80, 30))
        self.pushButton_reset.setFocusPolicy(QtCore.Qt.NoFocus)
        self.pushButton_reset.setObjectName("pushButton_reset")
        self.horizontalLayout_2.addWidget(self.pushButton_reset)
        self.pushButton_close = QtWidgets.QPushButton(self.widget_3)
        self.pushButton_close.setObjectName("pushButton_close")
        self.horizontalLayout_2.addWidget(self.pushButton_close)
        self.verticalLayout.addWidget(self.widget_3)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Shortcut"))
        self.label.setText(_translate("Dialog", "Shortcut"))
        self.pushButton_reset.setText(_translate("Dialog", "&Reset"))
        self.pushButton_close.setText(_translate("Dialog", "&Close"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/media/lg/disk2/PycharmProjects/ISAT_with_segment_anything/ISAT/ui/setting_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1280, 720)
        Dialog.setMinimumSize(QtCore.QSize(960, 600))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        Dialog.setFont(font)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.widget_2 = QtWidgets.QWidget(Dialog)
        self.widget_2.setMaximumSize(QtCore.QSize(16777215, 60))
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_4 = QtWidgets.QLabel(self.widget_2)
        self.label_4.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(20)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout.addWidget(self.label_4)
        self.verticalLayout_2.addWidget(self.widget_2)
        self.widget_21 = QtWidgets.QWidget(Dialog)
        self.widget_21.setMinimumSize(QtCore.QSize(300, 300))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setKerning(True)
        self.widget_21.setFont(font)
        self.widget_21.setObjectName("widget_21")
        self.gridLayout = QtWidgets.QGridLayout(self.widget_21)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.widget_23 = QtWidgets.QWidget(self.widget_21)
        self.widget_23.setObjectName("widget_23")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget_23)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.checkBox_polygon_invisible = QtWidgets.QCheckBox(self.widget_23)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_polygon_invisible.setFont(font)
        self.checkBox_polygon_invisible.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_polygon_invisible.setTristate(False)
        self.checkBox_polygon_invisible.setObjectName("checkBox_polygon_invisible")
        self.verticalLayout_5.addWidget(self.checkBox_polygon_invisible)
        self.widget_7 = QtWidgets.QWidget(self.widget_23)
        self.widget_7.setObjectName("widget_7")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.widget_7)
        self.horizontalLayout_6.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_3 = QtWidgets.QLabel(self.widget_7)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_6.addWidget(self.label_3)
        self.verticalLayout_5.addWidget(self.widget_7)
        self.gridLayout.addWidget(self.widget_23, 1, 0, 1, 1)
        self.widget_27 = QtWidgets.QWidget(self.widget_21)
        self.widget_27.setObjectName("widget_27")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.widget_27)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.checkBox_auto_save = QtWidgets.QCheckBox(self.widget_27)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_auto_save.setFont(font)
        self.checkBox_auto_save.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_auto_save.setObjectName("checkBox_auto_save")
        self.verticalLayout_4.addWidget(self.checkBox_auto_save)
        self.widget_19 = QtWidgets.QWidget(self.widget_27)
        self.widget_19.setObjectName("widget_19")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.widget_19)
        self.horizontalLayout_18.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.label_13 = QtWidgets.QLabel(self.widget_19)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_18.addWidget(self.label_13)
        self.verticalLayout_4.addWidget(self.widget_19)
        self.gridLayout.addWidget(self.widget_27, 0, 1, 1, 1)
        self.widget_29 = QtWidgets.QWidget(self.widget_21)
        self.widget_29.setObjectName("widget_29")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.widget_29)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.checkBox_use_bfloat16 = QtWidgets.QCheckBox(self.widget_29)
        self.checkBox_use_bfloat16.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_use_bfloat16.setFont(font)
        self.checkBox_use_bfloat16.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_use_bfloat16.setObjectName("checkBox_use_bfloat16")
        self.verticalLayout_8.addWidget(self.checkBox_use_bfloat16)
        self.widget_3 = QtWidgets.QWidget(self.widget_29)
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_2.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_5 = QtWidgets.QLabel(self.widget_3)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.verticalLayout_8.addWidget(self.widget_3)
        self.gridLayout.addWidget(self.widget_29, 2, 1, 1, 1)
        self.widget_30 = QtWidgets.QWidget(self.widget_21)
        self.widget_30.setObjectName("widget_30")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.widget_30)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.widget_15 = QtWidgets.QWidget(self.widget_30)
        self.widget_15.setObjectName("widget_15")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.widget_15)
        self.horizontalLayout_14.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_9 = QtWidgets.QLabel(self.widget_15)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_14.addWidget(self.label_9)
        self.horizontalSlider_vertex_size = QtWidgets.QSlider(self.widget_15)
        self.horizontalSlider_vertex_size.setMaximumSize(QtCore.QSize(200, 16777215))
        self.horizontalSlider_vertex_size.setFocusPolicy(QtCore.Qt.NoFocus)
        self.horizontalSlider_vertex_size.setMaximum(5)
        self.horizontalSlider_vertex_size.setPageStep(1)
        self.horizontalSlider_vertex_size.setTracking(True)
        self.horizontalSlider_vertex_size.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_vertex_size.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.horizontalSlider_vertex_size.setObjectName("horizontalSlider_vertex_size")
        self.horizontalLayout_14.addWidget(self.horizontalSlider_vertex_size)
        self.label_vertex_size = QtWidgets.QLabel(self.widget_15)
        self.label_vertex_size.setText("")
        self.label_vertex_size.setObjectName("label_vertex_size")
        self.horizontalLayout_14.addWidget(self.label_vertex_size)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem)
        self.verticalLayout_10.addWidget(self.widget_15)
        self.widget_16 = QtWidgets.QWidget(self.widget_30)
        self.widget_16.setObjectName("widget_16")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.widget_16)
        self.horizontalLayout_15.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_10 = QtWidgets.QLabel(self.widget_16)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_15.addWidget(self.label_10)
        self.verticalLayout_10.addWidget(self.widget_16)
        self.gridLayout.addWidget(self.widget_30, 4, 1, 1, 1)
        self.widget_22 = QtWidgets.QWidget(self.widget_21)
        self.widget_22.setObjectName("widget_22")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.widget_22)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.checkBox_approx_polygon = QtWidgets.QCheckBox(self.widget_22)
        self.checkBox_approx_polygon.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_approx_polygon.setFont(font)
        self.checkBox_approx_polygon.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_approx_polygon.setObjectName("checkBox_approx_polygon")
        self.verticalLayout_3.addWidget(self.checkBox_approx_polygon)
        self.widget_4 = QtWidgets.QWidget(self.widget_22)
        self.widget_4.setObjectName("widget_4")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.widget_4)
        self.horizontalLayout_5.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label = QtWidgets.QLabel(self.widget_4)
        self.label.setObjectName("label")
        self.horizontalLayout_5.addWidget(self.label)
        self.verticalLayout_3.addWidget(self.widget_4)
        self.gridLayout.addWidget(self.widget_22, 0, 0, 1, 1)
        self.widget_24 = QtWidgets.QWidget(self.widget_21)
        self.widget_24.setObjectName("widget_24")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.widget_24)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.checkBox_show_prompt = QtWidgets.QCheckBox(self.widget_24)
        self.checkBox_show_prompt.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_show_prompt.setFont(font)
        self.checkBox_show_prompt.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_show_prompt.setObjectName("checkBox_show_prompt")
        self.verticalLayout_7.addWidget(self.checkBox_show_prompt)
        self.widget_5 = QtWidgets.QWidget(self.widget_24)
        self.widget_5.setObjectName("widget_5")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget_5)
        self.horizontalLayout_4.setContentsMargins(20, 9, 9, 9)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_7 = QtWidgets.QLabel(self.widget_5)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_4.addWidget(self.label_7)
        self.verticalLayout_7.addWidget(self.widget_5)
        self.gridLayout.addWidget(self.widget_24, 2, 0, 1, 1)
        self.widget_28 = QtWidgets.QWidget(self.widget_21)
        self.widget_28.setObjectName("widget_28")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.widget_28)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.checkBox_show_edge = QtWidgets.QCheckBox(self.widget_28)
        self.checkBox_show_edge.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_show_edge.setFont(font)
        self.checkBox_show_edge.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_show_edge.setObjectName("checkBox_show_edge")
        self.verticalLayout_6.addWidget(self.checkBox_show_edge)
        self.widget_6 = QtWidgets.QWidget(self.widget_28)
        self.widget_6.setObjectName("widget_6")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget_6)
        self.horizontalLayout_3.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(self.widget_6)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.verticalLayout_6.addWidget(self.widget_6)
        self.gridLayout.addWidget(self.widget_28, 1, 1, 1, 1)
        self.widget_31 = QtWidgets.QWidget(self.widget_21)
        self.widget_31.setObjectName("widget_31")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.widget_31)
        self.verticalLayout.setObjectName("verticalLayout")
        self.checkBox_real_time_area = QtWidgets.QCheckBox(self.widget_31)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_real_time_area.setFont(font)
        self.checkBox_real_time_area.setObjectName("checkBox_real_time_area")
        self.verticalLayout.addWidget(self.checkBox_real_time_area)
        self.widget_9 = QtWidgets.QWidget(self.widget_31)
        self.widget_9.setObjectName("widget_9")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.widget_9)
        self.horizontalLayout_9.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_14 = QtWidgets.QLabel(self.widget_9)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_9.addWidget(self.label_14)
        self.verticalLayout.addWidget(self.widget_9)
        self.gridLayout.addWidget(self.widget_31, 3, 0, 1, 1)
        self.widget_25 = QtWidgets.QWidget(self.widget_21)
        self.widget_25.setObjectName("widget_25")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.widget_25)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.widget_8 = QtWidgets.QWidget(self.widget_25)
        self.widget_8.setObjectName("widget_8")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.widget_8)
        self.horizontalLayout_7.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_6 = QtWidgets.QLabel(self.widget_8)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_7.addWidget(self.label_6)
        self.horizontalSlider_mask_alpha = QtWidgets.QSlider(self.widget_8)
        self.horizontalSlider_mask_alpha.setMaximumSize(QtCore.QSize(200, 16777215))
        self.horizontalSlider_mask_alpha.setFocusPolicy(QtCore.Qt.NoFocus)
        self.horizontalSlider_mask_alpha.setMaximum(10)
        self.horizontalSlider_mask_alpha.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_mask_alpha.setInvertedAppearance(False)
        self.horizontalSlider_mask_alpha.setInvertedControls(False)
        self.horizontalSlider_mask_alpha.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.horizontalSlider_mask_alpha.setObjectName("horizontalSlider_mask_alpha")
        self.horizontalLayout_7.addWidget(self.horizontalSlider_mask_alpha)
        self.label_mask_alpha = QtWidgets.QLabel(self.widget_8)
        self.label_mask_alpha.setText("")
        self.label_mask_alpha.setObjectName("label_mask_alpha")
        self.horizontalLayout_7.addWidget(self.label_mask_alpha)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_9.addWidget(self.widget_8)
        self.widget_14 = QtWidgets.QWidget(self.widget_25)
        self.widget_14.setObjectName("widget_14")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.widget_14)
        self.horizontalLayout_13.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_8 = QtWidgets.QLabel(self.widget_14)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_13.addWidget(self.label_8)
        self.verticalLayout_9.addWidget(self.widget_14)
        self.gridLayout.addWidget(self.widget_25, 3, 1, 1, 1)
        self.widget_26 = QtWidgets.QWidget(self.widget_21)
        self.widget_26.setObjectName("widget_26")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.widget_26)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.widget_17 = QtWidgets.QWidget(self.widget_26)
        self.widget_17.setObjectName("widget_17")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.widget_17)
        self.horizontalLayout_16.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.label_11 = QtWidgets.QLabel(self.widget_17)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_16.addWidget(self.label_11)
        self.comboBox_contour_mode = QtWidgets.QComboBox(self.widget_17)
        self.comboBox_contour_mode.setMinimumSize(QtCore.QSize(120, 0))
        self.comboBox_contour_mode.setFocusPolicy(QtCore.Qt.ClickFocus)
        self.comboBox_contour_mode.setObjectName("comboBox_contour_mode")
        self.comboBox_contour_mode.addItem("")
        self.comboBox_contour_mode.addItem("")
        self.comboBox_contour_mode.addItem("")
        self.horizontalLayout_16.addWidget(self.comboBox_contour_mode)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem2)
        self.verticalLayout_11.addWidget(self.widget_17)
        self.widget_18 = QtWidgets.QWidget(self.widget_26)
        self.widget_18.setObjectName("widget_18")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.widget_18)
        self.horizontalLayout_17.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.label_12 = QtWidgets.QLabel(self.widget_18)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_17.addWidget(self.label_12)
        self.verticalLayout_11.addWidget(self.widget_18)
        self.gridLayout.addWidget(self.widget_26, 4, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.widget_21)
        self.widget = QtWidgets.QWidget(Dialog)
        self.widget.setMaximumSize(QtCore.QSize(16777215, 30))
        self.widget.setObjectName("widget")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        spacerItem3 = QtWidgets.QSpacerItem(1173, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem3)
        self.pushButton_close = QtWidgets.QPushButton(self.widget)
        self.pushButton_close.setObjectName("pushButton_close")
        self.horizontalLayout_8.addWidget(self.pushButton_close)
        self.verticalLayout_2.addWidget(self.widget)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Setting"))
        self.label_4.setText(_translate("Dialog", "Setting"))
        self.checkBox_polygon_invisible.setText(_translate("Dialog", "Polygons invisible"))
        self.label_3.setText(_translate("Dialog", "Hide polygons when in create mode."))
        self.checkBox_auto_save.setText(_translate("Dialog", "Auto save"))
        self.label_13.setText(_translate("Dialog", "Auto save."))
        self.checkBox_use_bfloat16.setText(_translate("Dialog", "Use bfloat16"))
        self.label_5.setText(_translate("Dialog", "Run sam on bfloat16 for smaller GPU memory footprint."))
        self.label_9.setText(_translate("Dialog", "Vertex size"))
        self.label_10.setText(_translate("Dialog", "The size of polygon vertexs."))
        self.checkBox_approx_polygon.setText(_translate("Dialog", "Approx polygon"))
        self.label.setText(_translate("Dialog", "Reduce the number of polygon vertics when genetating polygons from masks."))
        self.checkBox_show_prompt.setText(_translate("Dialog", "Show prompt"))
        self.label_7.setText(_translate("Dialog", "Show prompt point when using SAM."))
        self.checkBox_show_edge.setText(_translate("Dialog", "Show edge"))
        self.label_2.setText(_translate("Dialog", "Show edges of polygons."))
        self.checkBox_real_time_area.setText(_translate("Dialog", "Real time area"))
        self.label_14.setText(_translate("Dialog", "Calculate the area in real time while editing the polygon. If False update only when saving."))
        self.label_6.setText(_translate("Dialog", "Mask alpha"))
        self.label_8.setText(_translate("Dialog", "The transparency of the masks generated by SAM."))
        self.label_11.setText(_translate("Dialog", "Contour mode"))
        self.comboBox_contour_mode.setItemText(0, _translate("Dialog", "External"))
        self.comboBox_contour_mode.setItemText(1, _translate("Dialog", "Max only"))
        self.comboBox_contour_mode.setItemText(2, _translate("Dialog", "All"))
        self.label_12.setText(_translate("Dialog", "Contour saving mode. External contours or only max contour or all contours."))
        self.pushButton_close.setText(_translate("Dialog", "&Close"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/media/lg/disk2/PycharmProjects/ISAT_with_segment_anything/ISAT/ui/model_manager_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1280, 720)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        Dialog.setFont(font)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.widget_3 = QtWidgets.QWidget(Dialog)
        self.widget_3.setMaximumSize(QtCore.QSize(16777215, 60))
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.widget_3)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(20)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.verticalLayout.addWidget(self.widget_3)
        self.widget_4 = QtWidgets.QWidget(Dialog)
        self.widget_4.setMaximumSize(QtCore.QSize(16777215, 40))
        self.widget_4.setObjectName("widget_4")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget_4)
        self.horizontalLayout_3.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(self.widget_4)
        self.label_2.setMaximumSize(QtCore.QSize(30, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setText("")
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.widget_4)
        self.label_3.setMinimumSize(QtCore.QSize(80, 0))
        self.label_3.setMaximumSize(QtCore.QSize(80, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(self.widget_4)
        self.label_4.setMinimumSize(QtCore.QSize(80, 0))
        self.label_4.setMaximumSize(QtCore.QSize(80, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_4.setFont(font)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.label_5 = QtWidgets.QLabel(self.widget_4)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_5.setFont(font)
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_3.addWidget(self.label_5)
        self.label_6 = QtWidgets.QLabel(self.widget_4)
        self.label_6.setMaximumSize(QtCore.QSize(100, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_6.setFont(font)
        self.label_6.setAlignment(QtCore.Qt.AlignCenter)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_3.addWidget(self.label_6)
        self.label_7 = QtWidgets.QLabel(self.widget_4)
        self.label_7.setMaximumSize(QtCore.QSize(100, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_7.setFont(font)
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_3.addWidget(self.label_7)
        self.label_8 = QtWidgets.QLabel(self.widget_4)
        self.label_8.setMaximumSize(QtCore.QSize(300, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_8.setFont(font)
        self.label_8.setText("")
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_3.addWidget(self.label_8)
        self.verticalLayout.addWidget(self.widget_4)
        self.widget = QtWidgets.QWidget(Dialog)
        self.widget.setObjectName("widget")
        self.gridLayout = QtWidgets.QGridLayout(self.widget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout.addWidget(self.widget)
        self.widget_2 = QtWidgets.QWidget(Dialog)
        self.widget_2.setMaximumSize(QtCore.QSize(16777215, 30))
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButton_clear_tmp = QtWidgets.QPushButton(self.widget_2)
        self.pushButton_clear_tmp.setObjectName("pushButton_clear_tmp")
        self.horizontalLayout.addWidget(self.pushButton_clear_tmp)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButton_close = QtWidgets.QPushButton(self.widget_2)
        self.pushButton_close.setObjectName("pushButton_close")
        self.horizontalLayout.addWidget(self.pushButton_close)
        self.verticalLayout.addWidget(self.widget_2)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Model manage"))
        self.label.setText(_translate("Dialog", "Local SAM Model"))
        self.label_3.setText(_translate("Dialog", "Image"))
        self.label_4.setText(_translate("Dialog", "Video"))
        self.label_5.setText(_translate("Dialog", "Model name"))
        self.label_6.setText(_translate("Dialog", "GPU"))
        self.label_7.setText(_translate("Dialog", "Disk"))
        self.pushButton_clear_tmp.setText(_translate("Dialog", "Clear tmp"))
        self.pushButton_close.setText(_translate("Dialog", "&Close"))



# -*- coding: utf-8 -*-
# @Author  : LG

import os.path
import requests
from ISAT.ui.remote_sam_dialog import Ui_Dialog
from ISAT.configs import CHECKPOINT_PATH
from PyQt5 import QtWidgets, QtCore, QtGui
from PyQt5.QtGui import QValidator

class RemoteSamDialog(QtWidgets.QDialog, Ui_Dialog):
    def __init__(self, parent, mainwindow):
        super(RemoteSamDialog, self).__init__(parent)
        self.mainwindow = mainwindow
        self.setupUi(self)

        self.remote_sam_model_name = None

        self.setWindowModality(QtCore.Qt.WindowModality.WindowModal)
        self.checkBox_use_remote.setEnabled(False)
        self.frame_info.setVisible(False)
        self.lineEdit_host.setValidator(IPv4Validator())

        self.pushButton_check.clicked.connect(self.check_connection)
        self.checkBox_use_remote.stateChanged.connect(self.use_remote_sam)
        self.pushButton_close.clicked.connect(self.close)

    def check_connection(self):
        host = self.lineEdit_host.text()
        port = self.lineEdit_port.text()
        try:
            response = requests.get(f"http://{host}:{port}/api/info")
            if response.status_code != 200:
                QtWidgets.QMessageBox.warning(self, "Error", f"Could not connect to remote Sam, status_code: {response.status_code}")
                return
            checkpoint = response.json()['checkpoint']
            device = response.json()['device']
            dtype = response.json()['dtype']

            try:
                model_name = os.path.split(checkpoint)[-1]

                self.frame_info.setVisible(True)
                self.label_name.setText(model_name)
                self.label_device.setText(device)
                self.label_dtype.setText(dtype)

                self.checkBox_use_remote.setEnabled(True)

            except Exception as e:
                self.frame_info.setVisible(False)
                self.checkBox_use_remote.setEnabled(False)
                QtWidgets.QMessageBox.warning(self, "Error", str(e))

        except requests.exceptions.RequestException as e:
            self.frame_info.setVisible(False)
            self.checkBox_use_remote.setEnabled(False)
            QtWidgets.QMessageBox.warning(self, "Error", str(e))

    def use_remote_sam(self, check_state):
        if check_state == QtCore.Qt.CheckState.Checked:
            model_name = self.label_name.text()
            if not os.path.exists(os.path.join(CHECKPOINT_PATH, model_name)):
                self.mainwindow.use_remote_sam = False
                QtWidgets.QMessageBox.warning(self, "Error", f"Local model {model_name} does not exist.")
            else:
                try:
                    self.mainwindow.use_remote_sam = True
                    self.mainwindow.init_segment_anything(model_name, checked=True)
                except Exception as e:
                    self.mainwindow.use_remote_sam = False
                    QtWidgets.QMessageBox.warning(self, "Error", f"Init local sam failed.\n {e}")

        else:
            self.mainwindow.use_remote_sam = False

        state = QtCore.Qt.CheckState.Checked if self.mainwindow.use_remote_sam else QtCore.Qt.CheckState.Unchecked
        self.sender().setCheckState(state)
        self.lineEdit_host.setEnabled(not self.mainwindow.use_remote_sam)
        self.lineEdit_port.setEnabled(not self.mainwindow.use_remote_sam)
        self.pushButton_check.setEnabled(not self.mainwindow.use_remote_sam)

class IPv4Validator(QValidator):
    def validate(self, input_str, pos):
        parts = input_str.split('.')
        if len(parts) > 4:
            # 返回 Invalid + 原始输入 + 光标位置
            return (QValidator.Invalid, input_str, pos)

        for i, part in enumerate(parts):
            if i < len(parts) - 1 and not part:
                return (QValidator.Invalid, input_str, pos)
            if part:
                if not part.isdigit() or len(part) > 3:
                    return (QValidator.Invalid, input_str, pos)
                num = int(part)
                if num < 0 or num > 255:
                    return (QValidator.Invalid, input_str, pos)

        if len(parts) == 4:
            if not parts[3]:
                # 允许中间状态（如 192.168.1.）
                return (QValidator.Intermediate, input_str, pos)
            elif 0 <= int(parts[3]) <= 255:
                return (QValidator.Acceptable, input_str, pos)
            else:
                return (QValidator.Invalid, input_str, pos)
        else:
            # 允许继续输入（如 192.168）
            return (QValidator.Intermediate, input_str, pos)



# -*- coding: utf-8 -*-
# @Author  : LG
import os

from ISAT.ui.process_exif_dialog import Ui_Dialog
from PyQt5 import QtWidgets, QtCore, QtGui
from PIL import Image, ImageOps


class ProcessExifDialog(QtWidgets.QDialog, Ui_Dialog):
    def __init__(self, parent, mainwindow):
        super().__init__(parent=parent)
        self.setupUi(self)
        self.mainwindow = mainwindow

        self.setWindowModality(QtCore.Qt.WindowModality.WindowModal)

        self.radioButton_apply_exif.setChecked(True)
        self.pushButton_image_root.clicked.connect(self.open_dir)
        self.pushButton_save_root.clicked.connect(self.open_dir)
        self.pushButton_start.clicked.connect(self.start)
        self.pushButton_close.clicked.connect(self.close)

    def open_dir(self):
        dir = QtWidgets.QFileDialog.getExistingDirectory(self, caption='Open dir')
        if self.sender() == self.pushButton_image_root:
            lineEdit = self.lineEdit_image_root
        elif self.sender() == self.pushButton_save_root:
            lineEdit = self.lineEdit_save_root
        else:
            return
        if dir:
            lineEdit.setText(dir)
        else:
            lineEdit.clear()

    def start(self):
        self.pushButton_start.setEnabled(False)
        self.textBrowser.clear()
        self.progressBar.reset()

        image_root = self.lineEdit_image_root.text()
        save_root = self.lineEdit_save_root.text()
        apply_exif = self.radioButton_apply_exif.isChecked()

        if not (image_root or save_root):
            self.pushButton_start.setEnabled(True)
            return

        images = os.listdir(image_root)
        self.progressBar.setMaximum(len(images))

        for index, image_name in enumerate(images):
            self.textBrowser.append('{:>8d} - Processing - {}'.format(index, image_name))
            try:
                image = Image.open(os.path.join(image_root, image_name))
            except:
                self.textBrowser.append('{} Invalid image.'.format(' '*10))
                image = None

            if image is not None:
                exif_info = image.getexif()
                if exif_info and exif_info.get(274, 1) != 1:
                    self.textBrowser.append('{} Has rotation tag.'.format(' ' * 10, ))
                    if apply_exif:
                        self.textBrowser.append('{} Ori size    : w-{} h-{}.'.format(' ' * 10, image.width, image.height))
                        image = ImageOps.exif_transpose(image)
                        self.textBrowser.append('{} Rotated size: w-{} h-{}.'.format(' ' * 10, image.width, image.height))
                    image.save(os.path.join(save_root, image_name))
                    self.textBrowser.append('{} Resave finished'.format(' '* 10))
                else:
                    self.textBrowser.append('{} No rotation tag.'.format(' '*10))

            self.progressBar.setValue(index + 1)

        self.pushButton_start.setEnabled(True)




# -*- coding: utf-8 -*-
# @Author  : LG

from PyQt5 import QtWidgets, QtCore, QtGui
from PyQt5.QtCore import QThread, pyqtSignal
from ISAT.ui.model_manager_dialog import Ui_Dialog
from ISAT.configs import CHECKPOINT_PATH
from ISAT.segment_any.model_zoo import model_dict
from urllib import request
from functools import partial
import shutil
import time
import os


class DownloadThread(QThread):
    tag = pyqtSignal(float, float)

    def __init__(self, parent=None):
        super(DownloadThread, self).__init__(parent)
        self.urls = None
        self.name = None
        self.pause = False

        self.block_size = 4096

    def setNameAndUrl(self, name, urls):
        self.urls = urls
        self.name = name
        self.pause = False

    def run(self):
        if self.name is not None and self.urls is not None:
            tmp_root = os.path.join(CHECKPOINT_PATH, 'tmp')
            if not os.path.exists(tmp_root):
                os.mkdir(tmp_root)

            # 寻找最佳下载链接
            best_time = 1e8
            best_url = self.urls[0]
            for url in self.urls:
                try:
                    start_time = time.time()
                    req = request.Request(url, headers={"Range": "bytes=0-10"})
                    request.urlopen(req, timeout=5)
                    cost_time = time.time() - start_time
                except:
                    cost_time = 1e8
                if cost_time < best_time:
                    best_time = cost_time
                    best_url = url

            print('Download {} from {}'.format(self.name,  best_url))
            # 检查缓存
            downloaded_size = 0
            download_tmp = os.path.join(tmp_root, self.name)
            if os.path.exists(download_tmp):
                with open(download_tmp, 'rb') as f:
                    downloaded_size = len(f.read())

            req = request.Request(best_url, headers={"Range": "bytes=0-"})
            try:
                response = request.urlopen(req, timeout=10)
                total_size = int(response.headers['Content-Length'])
            except Exception as e:
                print('When download {} from {}, {}'.format(self.name, best_url, e))
                return
            # 存在缓存
            if downloaded_size != 0:
                # 判断缓存文件是否下载完
                if downloaded_size > total_size:
                    self.move_from_tmp(download_tmp, os.path.join(CHECKPOINT_PATH, self.name))
                    return
                # 断点续传
                content_range = response.headers.get('Content-Range', None)
                if content_range is not None:
                    req = request.Request(best_url, headers={"Range": "bytes={}-".format(downloaded_size)})
                    response = request.urlopen(req)
                    content_range = response.headers.get('Content-Range', None)
                    if content_range is not None:
                        print('Resume downloading: ', content_range)
                else:
                    print('Not supprot resume download.')
                    downloaded_size = 0

            open_mode = 'wb' if downloaded_size == 0 else 'ab'
            with open(download_tmp, open_mode) as f:
                while True:
                    if self.pause:
                        self.tag.emit(-1, -1)
                        return
                    buffer = response.read(self.block_size)
                    if not buffer:
                        break
                    f.write(buffer)
                    downloaded_size += len(buffer)
                    self.tag.emit(downloaded_size, total_size)
            # 下载完成
            self.move_from_tmp(download_tmp, os.path.join(CHECKPOINT_PATH, self.name))

    def move_from_tmp(self, from_path, to_path):
        try:
            shutil.move(from_path, to_path)
            self.tag.emit(-2, -2)

        except Exception as e:
            print('Error when move {} to {}, {}'.format(from_path, to_path, e))

class ModelManagerDialog(QtWidgets.QDialog, Ui_Dialog):
    def __init__(self, parent, mainwindow):
        super(ModelManagerDialog, self).__init__(parent)
        self.mainwindow = mainwindow
        self.setupUi(self)
        self.setWindowModality(QtCore.Qt.WindowModality.WindowModal)
        self.download_thread_dict = {}
        self.init_ui()
        self.pushButton_clear_tmp.clicked.connect(self.clear_tmp)
        self.pushButton_close.clicked.connect(self.close)

    def init_ui(self):
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)

        for i in range(self.gridLayout.count()):
            self.gridLayout.itemAt(i).widget().deleteLater()

        for index, (model_name, info_dict) in enumerate(model_dict.items()):
            url = info_dict.get('url', '')
            memory = info_dict.get('memory', '')
            bf16_memory = info_dict.get('bf16_memory', '')
            params = info_dict.get('params', '')
            image_segment = info_dict.get('image_segment', False)
            video_segment = info_dict.get('video_segment', False)
            # radio
            radio = QtWidgets.QRadioButton()
            radio.setFixedWidth(30)
            radio.toggled.connect(partial(self.mainwindow.init_segment_anything, model_name))
            radio.setEnabled(False)
            # image seg
            image_segment_label = QtWidgets.QLabel()
            pixmap = QtGui.QPixmap(":/icon/icons/校验-小_check-small.svg") if image_segment else QtGui.QPixmap(":/icon/icons/关闭-小_close-small.svg")
            image_segment_label.setPixmap(pixmap)
            image_segment_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
            image_segment_label.setFixedWidth(80)
            image_segment_label.setStyleSheet('background-color: rgb(240, 240, 240);' if index % 2 else 'background-color: rgb(255, 255, 255);')
            # video seg
            video_segment_label = QtWidgets.QLabel()
            pixmap = QtGui.QPixmap(":/icon/icons/校验-小_check-small.svg") if video_segment else QtGui.QPixmap(":/icon/icons/关闭-小_close-small.svg")
            video_segment_label.setPixmap(pixmap)
            video_segment_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
            video_segment_label.setFixedWidth(80)
            video_segment_label.setStyleSheet('background-color: rgb(240, 240, 240);' if index % 2 else 'background-color: rgb(255, 255, 255);')
            # model name
            name_label = QtWidgets.QLabel()
            name_label.setFont(font)
            name_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeft)
            name_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignVCenter)
            name_label.setText(model_name)
            name_label.setStyleSheet('background-color: rgb(240, 240, 240);' if index % 2 else 'background-color: rgb(255, 255, 255);')
            # 显存占用
            memory_label = QtWidgets.QLabel()
            memory_label.setFont(font)
            memory_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
            memory_label.setText(bf16_memory)
            memory_label.setFixedWidth(100)
            memory_label.setStyleSheet('background-color: rgb(240, 240, 240);' if index % 2 else 'background-color: rgb(255, 255, 255);')
            # 权重大小
            params_label = QtWidgets.QLabel()
            params_label.setFont(font)
            params_label.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
            params_label.setText(params)
            params_label.setFixedWidth(100)
            params_label.setStyleSheet('background-color: rgb(240, 240, 240);' if index % 2 else 'background-color: rgb(255, 255, 255);')
            # 下载/删除按钮
            ops_button = QtWidgets.QPushButton()
            ops_button.setFixedWidth(300)
            ops_button.setFixedHeight(30)
            ops_button.setFocusPolicy(QtCore.Qt.FocusPolicy.ClickFocus)
            ops_button.setFont(font)

            if os.path.exists(os.path.join(CHECKPOINT_PATH, model_name)):
                # ops_button.setStyleSheet('QWidget {background-color: %s}' % 'red')
                ops_button.setStyleSheet('QWidget {color: %s}' % 'red')
                ops_button.setText('delete')
                ops_button.clicked.connect(partial(self.delete, model_name))
                radio.setEnabled(True)
            else:
                # ops_button.setStyleSheet('QWidget {background-color: %s}' % 'green')
                ops_button.setStyleSheet('QWidget {color: %s}' % 'green')
                ops_button.setText('download')
                ops_button.clicked.connect(partial(self.download, model_name))

            self.gridLayout.addWidget(radio, index, 0, 1, 1)
            self.gridLayout.addWidget(image_segment_label, index, 1, 1, 1)
            self.gridLayout.addWidget(video_segment_label, index, 2, 1, 1)
            self.gridLayout.addWidget(name_label, index, 3, 1, 1)
            self.gridLayout.addWidget(memory_label, index, 4, 1, 1)
            self.gridLayout.addWidget(params_label, index, 5, 1, 1)
            self.gridLayout.addWidget(ops_button, index, 6, 1, 1)


    def update_ui(self):
        for index, (model_name, info_dict) in enumerate(model_dict.items()):
            url = info_dict.get('url', '')
            memory = info_dict.get('memory', '')
            bf16_memory = info_dict.get('bf16_memory', '')
            params = info_dict.get('params', '')
            image_segment = info_dict.get('image_segment', False)
            video_segment = info_dict.get('video_segment', False)

            radio = self.gridLayout.itemAtPosition(index, 0).widget()
            image_segment_label = self.gridLayout.itemAtPosition(index, 1).widget()
            video_segment_label = self.gridLayout.itemAtPosition(index, 2).widget()
            name_label = self.gridLayout.itemAtPosition(index, 3).widget()
            memory_label = self.gridLayout.itemAtPosition(index, 4).widget()
            params_label = self.gridLayout.itemAtPosition(index, 5).widget()
            ops_button = self.gridLayout.itemAtPosition(index, 6).widget()

            radio.blockSignals(True)
            if self.mainwindow.use_segment_anything:
                current_model_name = os.path.split(self.mainwindow.segany.checkpoint)[-1]
                radio.setChecked(current_model_name == model_name)
            else:
                radio.setChecked(False)
            radio.blockSignals(False)

            memory_label.setText(bf16_memory if self.mainwindow.cfg['software']['use_bfloat16'] else memory)

            if os.path.exists(os.path.join(CHECKPOINT_PATH, model_name)):
                # ops_button.setStyleSheet('QWidget {background-color: %s}' % 'red')
                ops_button.setStyleSheet('QWidget {color: %s}' % 'red')
                ops_button.setText('delete')
                ops_button.clicked.connect(partial(self.delete, model_name))
                radio.setEnabled(True)
            else:
                # ops_button.setStyleSheet('QWidget {background-color: %s}' % 'green')
                ops_button.setStyleSheet('QWidget {color: %s}' % 'green')
                ops_button.setText('download')
                ops_button.clicked.connect(partial(self.download, model_name))
                radio.setEnabled(False)

    def download(self, model_name):
        button = self.sender()
        button.setText('downloading')
        info_dict = model_dict.get(model_name, {})
        urls = info_dict.get('urls', None)

        if model_name in self.download_thread_dict:
            download_thread = self.download_thread_dict[model_name]
        else:
            download_thread = DownloadThread(self)
            self.download_thread_dict[model_name] = download_thread

        download_thread.setNameAndUrl(model_name, urls)
        download_thread.tag.connect(partial(self.download_process, button, model_name))
        download_thread.start()

        button.setEnabled(False)
        button.clicked.connect(partial(self.pause, model_name))
        button.setEnabled(True)

    def download_process(self, button:QtWidgets.QPushButton, model_name, downloaded_size, total_size):
        if downloaded_size == -1 and total_size == -1:
            button.setText('continue')
            button.setEnabled(False)
            button.clicked.connect(partial(self.download, model_name))
            button.setEnabled(True)

        elif downloaded_size == -2 and total_size == -2:
            button.setText('delete')
            button.setStyleSheet('QWidget {color: %s}' % 'red')
            button.setEnabled(False)
            button.clicked.connect(partial(self.delete, model_name))
            button.setEnabled(True)
            # self.mainwindow.update_menuSAM()
            self.update_ui()
        else:
            button.setText('{:.2f}% - {}/{}M'.format(downloaded_size/total_size*100, downloaded_size//1000000, total_size//1000000))

    def pause(self, model_name):
        download_thread:DownloadThread = self.download_thread_dict[model_name]
        download_thread.pause = True

    def delete(self, model_name):
        button = self.sender()
        try:
            os.remove(os.path.join(CHECKPOINT_PATH, model_name))
            button.setText('download')
            button.setStyleSheet('QWidget {color: %s}' % 'green')
            button.setEnabled(False)
            button.clicked.connect(partial(self.download, model_name))
            button.setEnabled(True)
        except Exception as e:
            print('Error when remove {}, {}'.format(
                os.path.join(CHECKPOINT_PATH, model_name), e))
        self.update_ui()

    def clear_tmp(self):
        remove_list = []
        for name in os.listdir(os.path.join(CHECKPOINT_PATH, 'tmp')):
            tmp_file = os.path.join(CHECKPOINT_PATH, 'tmp', name)
            if name in self.download_thread_dict:
                thread = self.download_thread_dict.get(name, None)
                if thread is not None:
                    if thread.isRunning():
                        continue
            try:
                os.remove(tmp_file)
                remove_list.append(tmp_file)

            except Exception as e:
                print('Error when remove {}, {}'.format(
                    os.path.join(CHECKPOINT_PATH, name), e))
        QtWidgets.QMessageBox.information(
            self,
            'clear tmp',
            'Remove tmp: [' + '],['.join(remove_list) + ']'
        )



# -*- coding: utf-8 -*-
# @Author  : LG

from PyQt5 import QtCore, QtGui, QtWidgets
from ISAT.ui.setting_dialog import Ui_Dialog

class SettingDialog(QtWidgets.QDialog, Ui_Dialog):
    def __init__(self, parent, mainwindow):
        QtWidgets.QDialog.__init__(self, parent)
        self.mainwindow = mainwindow
        self.setupUi(self)
        self.setWindowModality(QtCore.Qt.WindowModality.WindowModal)

        self.checkBox_auto_save.stateChanged.connect(self.mainwindow.change_auto_save_state)
        self.checkBox_real_time_area.stateChanged.connect(self.mainwindow.change_real_time_area_state)
        self.checkBox_approx_polygon.stateChanged.connect(self.mainwindow.change_approx_polygon_state)
        self.checkBox_polygon_invisible.stateChanged.connect(self.mainwindow.change_create_mode_invisible_polygon_state)
        self.checkBox_show_edge.stateChanged.connect(self.mainwindow.change_edge_state)
        self.checkBox_show_prompt.stateChanged.connect(self.mainwindow.change_prompt_visiable)
        self.checkBox_use_bfloat16.stateChanged.connect(self.mainwindow.change_bfloat16_state)
        self.horizontalSlider_vertex_size.valueChanged.connect(self.mainwindow.change_vertex_size)
        self.horizontalSlider_mask_alpha.valueChanged.connect(self.mainwindow.change_mask_aplha)
        self.comboBox_contour_mode.currentIndexChanged.connect(self.contour_mode_index_changed)
        self.pushButton_close.clicked.connect(self.close)

    def contour_mode_index_changed(self, index):
        if index == 0:
            contour_mode = 'external'
        elif index == 1:
            contour_mode = 'max_only'
        else:
            contour_mode = 'all'
        self.mainwindow.change_contour_mode(contour_mode)


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'D:\PycharmProjects\ISAT_with_segment_anything\ISAT\ui\MainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1600, 900)
        MainWindow.setMinimumSize(QtCore.QSize(800, 600))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icon/icons/ISAT13_100.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setEnabled(True)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1600, 25))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menubar.setFont(font)
        self.menubar.setAutoFillBackground(False)
        self.menubar.setDefaultUp(False)
        self.menubar.setNativeMenuBar(True)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menuFile.setFont(font)
        self.menuFile.setObjectName("menuFile")
        self.menuView = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menuView.setFont(font)
        self.menuView.setObjectName("menuView")
        self.menuAbout = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menuAbout.setFont(font)
        self.menuAbout.setObjectName("menuAbout")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setEnabled(True)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menuTools.setFont(font)
        self.menuTools.setObjectName("menuTools")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.menuEdit.setFont(font)
        self.menuEdit.setObjectName("menuEdit")
        self.menuSAM_model = QtWidgets.QMenu(self.menubar)
        self.menuSAM_model.setObjectName("menuSAM_model")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.toolBar.setFont(font)
        self.toolBar.setIconSize(QtCore.QSize(24, 24))
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setFloatable(False)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.info_dock = QtWidgets.QDockWidget(MainWindow)
        self.info_dock.setMinimumSize(QtCore.QSize(85, 43))
        self.info_dock.setFeatures(QtWidgets.QDockWidget.AllDockWidgetFeatures)
        self.info_dock.setObjectName("info_dock")
        self.dockWidgetContents_2 = QtWidgets.QWidget()
        self.dockWidgetContents_2.setObjectName("dockWidgetContents_2")
        self.info_dock.setWidget(self.dockWidgetContents_2)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.info_dock)
        self.annos_dock = QtWidgets.QDockWidget(MainWindow)
        self.annos_dock.setMinimumSize(QtCore.QSize(85, 43))
        self.annos_dock.setFeatures(QtWidgets.QDockWidget.AllDockWidgetFeatures)
        self.annos_dock.setObjectName("annos_dock")
        self.dockWidgetContents_3 = QtWidgets.QWidget()
        self.dockWidgetContents_3.setObjectName("dockWidgetContents_3")
        self.annos_dock.setWidget(self.dockWidgetContents_3)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.annos_dock)
        self.files_dock = QtWidgets.QDockWidget(MainWindow)
        self.files_dock.setObjectName("files_dock")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.files_dock.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.files_dock)
        self.categories_dock = QtWidgets.QDockWidget(MainWindow)
        self.categories_dock.setObjectName("categories_dock")
        self.dockWidgetContents_4 = QtWidgets.QWidget()
        self.dockWidgetContents_4.setObjectName("dockWidgetContents_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.dockWidgetContents_4)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.categories_dock.setWidget(self.dockWidgetContents_4)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.categories_dock)
        self.toolBar_2 = QtWidgets.QToolBar(MainWindow)
        self.toolBar_2.setMovable(False)
        self.toolBar_2.setFloatable(False)
        self.toolBar_2.setObjectName("toolBar_2")
        MainWindow.addToolBar(QtCore.Qt.RightToolBarArea, self.toolBar_2)
        self.actionImages_dir = QtWidgets.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icon/icons/照片_pic.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionImages_dir.setIcon(icon1)
        self.actionImages_dir.setObjectName("actionImages_dir")
        self.actionZoom_in = QtWidgets.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icon/icons/放大_zoom-in.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionZoom_in.setIcon(icon2)
        self.actionZoom_in.setObjectName("actionZoom_in")
        self.actionZoom_out = QtWidgets.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icon/icons/缩小_zoom-out.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionZoom_out.setIcon(icon3)
        self.actionZoom_out.setObjectName("actionZoom_out")
        self.actionFit_window = QtWidgets.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icon/icons/全宽_fullwidth.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFit_window.setIcon(icon4)
        self.actionFit_window.setObjectName("actionFit_window")
        self.actionSetting = QtWidgets.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icon/icons/设置_setting-two.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSetting.setIcon(icon5)
        self.actionSetting.setObjectName("actionSetting")
        self.actionExit = QtWidgets.QAction(MainWindow)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icon/icons/开关_power.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExit.setIcon(icon6)
        self.actionExit.setObjectName("actionExit")
        self.actionLabel_dir = QtWidgets.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icon/icons/文件夹-开_folder-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionLabel_dir.setIcon(icon7)
        self.actionLabel_dir.setObjectName("actionLabel_dir")
        self.actionSave = QtWidgets.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icon/icons/保存_save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave.setIcon(icon8)
        self.actionSave.setObjectName("actionSave")
        self.actionPrev_image = QtWidgets.QAction(MainWindow)
        self.actionPrev_image.setCheckable(False)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icon/icons/上一步_back.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPrev_image.setIcon(icon9)
        self.actionPrev_image.setMenuRole(QtWidgets.QAction.TextHeuristicRole)
        self.actionPrev_image.setPriority(QtWidgets.QAction.NormalPriority)
        self.actionPrev_image.setObjectName("actionPrev_image")
        self.actionNext_image = QtWidgets.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icon/icons/下一步_next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNext_image.setIcon(icon10)
        self.actionNext_image.setObjectName("actionNext_image")
        self.actionShortcut = QtWidgets.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icon/icons/键盘_keyboard-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionShortcut.setIcon(icon11)
        self.actionShortcut.setObjectName("actionShortcut")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icon/icons/ISAT13.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAbout.setIcon(icon12)
        self.actionAbout.setObjectName("actionAbout")
        self.actionSegment_anything_point = QtWidgets.QAction(MainWindow)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icon/icons/M_Favicon.ico"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSegment_anything_point.setIcon(icon13)
        self.actionSegment_anything_point.setObjectName("actionSegment_anything_point")
        self.actionDelete = QtWidgets.QAction(MainWindow)
        self.actionDelete.setEnabled(False)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icon/icons/删除_delete.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDelete.setIcon(icon14)
        self.actionDelete.setObjectName("actionDelete")
        self.actionBit_map = QtWidgets.QAction(MainWindow)
        self.actionBit_map.setCheckable(False)
        self.actionBit_map.setIcon(icon1)
        self.actionBit_map.setObjectName("actionBit_map")
        self.actionEdit = QtWidgets.QAction(MainWindow)
        self.actionEdit.setEnabled(False)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icon/icons/编辑_edit.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEdit.setIcon(icon15)
        self.actionEdit.setObjectName("actionEdit")
        self.actionTo_top = QtWidgets.QAction(MainWindow)
        self.actionTo_top.setEnabled(False)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icon/icons/去顶部_to-top.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionTo_top.setIcon(icon16)
        self.actionTo_top.setObjectName("actionTo_top")
        self.actionTo_bottom = QtWidgets.QAction(MainWindow)
        self.actionTo_bottom.setEnabled(False)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icon/icons/去底部_to-bottom.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionTo_bottom.setIcon(icon17)
        self.actionTo_bottom.setObjectName("actionTo_bottom")
        self.actionBackspace = QtWidgets.QAction(MainWindow)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/icon/icons/删除_delete-two.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionBackspace.setIcon(icon18)
        self.actionBackspace.setObjectName("actionBackspace")
        self.actionCancel = QtWidgets.QAction(MainWindow)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/icon/icons/关闭_close-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCancel.setIcon(icon19)
        self.actionCancel.setObjectName("actionCancel")
        self.actionFinish = QtWidgets.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/icon/icons/校验_check-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFinish.setIcon(icon20)
        self.actionFinish.setObjectName("actionFinish")
        self.actionPolygon = QtWidgets.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/icon/icons/锚点_anchor.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPolygon.setIcon(icon21)
        self.actionPolygon.setObjectName("actionPolygon")
        self.actionVisible = QtWidgets.QAction(MainWindow)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(":/icon/icons/眼睛_eyes.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVisible.setIcon(icon22)
        self.actionVisible.setObjectName("actionVisible")
        self.actionModel_manage = QtWidgets.QAction(MainWindow)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(":/icon/icons/列表_list-middle.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionModel_manage.setIcon(icon23)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        self.actionModel_manage.setFont(font)
        self.actionModel_manage.setObjectName("actionModel_manage")
        self.actionConverter = QtWidgets.QAction(MainWindow)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(":/icon/icons/转换文件夹1_folder-conversion-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionConverter.setIcon(icon24)
        self.actionConverter.setObjectName("actionConverter")
        self.actionAuto_segment_with_bounding_box = QtWidgets.QAction(MainWindow)
        self.actionAuto_segment_with_bounding_box.setIcon(icon13)
        self.actionAuto_segment_with_bounding_box.setObjectName("actionAuto_segment_with_bounding_box")
        self.actionAnno_validator = QtWidgets.QAction(MainWindow)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(":/icon/icons/检查_inspection.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAnno_validator.setIcon(icon25)
        self.actionAnno_validator.setObjectName("actionAnno_validator")
        self.actionCopy = QtWidgets.QAction(MainWindow)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(":/icon/icons/复制_copy.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopy.setIcon(icon26)
        self.actionCopy.setObjectName("actionCopy")
        self.actionUnion = QtWidgets.QAction(MainWindow)
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(":/icon/icons/合并选择_union-selection.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionUnion.setIcon(icon27)
        self.actionUnion.setObjectName("actionUnion")
        self.actionSubtract = QtWidgets.QAction(MainWindow)
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(":/icon/icons/减去上一层_subtract-selection-one.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSubtract.setIcon(icon28)
        self.actionSubtract.setObjectName("actionSubtract")
        self.actionIntersect = QtWidgets.QAction(MainWindow)
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(":/icon/icons/相交选择_intersect-selection.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIntersect.setIcon(icon29)
        self.actionIntersect.setObjectName("actionIntersect")
        self.actionExclude = QtWidgets.QAction(MainWindow)
        icon30 = QtGui.QIcon()
        icon30.addPixmap(QtGui.QPixmap(":/icon/icons/排除选择_exclude-selection.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExclude.setIcon(icon30)
        self.actionExclude.setObjectName("actionExclude")
        self.actionVideo_segment = QtWidgets.QAction(MainWindow)
        icon31 = QtGui.QIcon()
        icon31.addPixmap(QtGui.QPixmap(":/icon/icons/play-all.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVideo_segment.setIcon(icon31)
        self.actionVideo_segment.setObjectName("actionVideo_segment")
        self.actionVideo_segment_once = QtWidgets.QAction(MainWindow)
        icon32 = QtGui.QIcon()
        icon32.addPixmap(QtGui.QPixmap(":/icon/icons/play-1.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVideo_segment_once.setIcon(icon32)
        self.actionVideo_segment_once.setObjectName("actionVideo_segment_once")
        self.actionVideo_segment_five_times = QtWidgets.QAction(MainWindow)
        icon33 = QtGui.QIcon()
        icon33.addPixmap(QtGui.QPixmap(":/icon/icons/play-5.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVideo_segment_five_times.setIcon(icon33)
        self.actionVideo_segment_five_times.setObjectName("actionVideo_segment_five_times")
        self.actionVideo_to_frames = QtWidgets.QAction(MainWindow)
        icon34 = QtGui.QIcon()
        icon34.addPixmap(QtGui.QPixmap(":/icon/icons/视频_video-two.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionVideo_to_frames.setIcon(icon34)
        self.actionVideo_to_frames.setObjectName("actionVideo_to_frames")
        self.actionSegment_anything_box = QtWidgets.QAction(MainWindow)
        icon35 = QtGui.QIcon()
        icon35.addPixmap(QtGui.QPixmap(":/icon/icons/小矩形_rectangle-small.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSegment_anything_box.setIcon(icon35)
        self.actionSegment_anything_box.setObjectName("actionSegment_anything_box")
        self.actionPrev_group = QtWidgets.QAction(MainWindow)
        self.actionPrev_group.setIcon(icon9)
        self.actionPrev_group.setObjectName("actionPrev_group")
        self.actionNext_group = QtWidgets.QAction(MainWindow)
        self.actionNext_group.setIcon(icon10)
        self.actionNext_group.setObjectName("actionNext_group")
        self.actionRepaint = QtWidgets.QAction(MainWindow)
        icon36 = QtGui.QIcon()
        icon36.addPixmap(QtGui.QPixmap(":/icon/icons/编辑撰写_writing-fluently.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionRepaint.setIcon(icon36)
        self.actionRepaint.setObjectName("actionRepaint")
        self.actionScene_shot = QtWidgets.QAction(MainWindow)
        icon37 = QtGui.QIcon()
        icon37.addPixmap(QtGui.QPixmap(":/icon/icons/截屏_screenshot-two.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionScene_shot.setIcon(icon37)
        self.actionScene_shot.setObjectName("actionScene_shot")
        self.actionWindow_shot = QtWidgets.QAction(MainWindow)
        self.actionWindow_shot.setIcon(icon37)
        self.actionWindow_shot.setObjectName("actionWindow_shot")
        self.actionLanguage = QtWidgets.QAction(MainWindow)
        icon38 = QtGui.QIcon()
        icon38.addPixmap(QtGui.QPixmap(":/icon/icons/中文_chinese.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionLanguage.setIcon(icon38)
        self.actionLanguage.setObjectName("actionLanguage")
        self.actionRemote_SAM = QtWidgets.QAction(MainWindow)
        icon39 = QtGui.QIcon()
        icon39.addPixmap(QtGui.QPixmap(":/icon/icons/云运行_link-cloud.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionRemote_SAM.setIcon(icon39)
        self.actionRemote_SAM.setObjectName("actionRemote_SAM")
        self.actionProcess_EXIF_tag = QtWidgets.QAction(MainWindow)
        self.actionProcess_EXIF_tag.setIcon(icon1)
        self.actionProcess_EXIF_tag.setObjectName("actionProcess_EXIF_tag")
        self.menuFile.addAction(self.actionImages_dir)
        self.menuFile.addAction(self.actionLabel_dir)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionPrev_image)
        self.menuFile.addAction(self.actionNext_image)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSetting)
        self.menuFile.addAction(self.actionExit)
        self.menuView.addSeparator()
        self.menuView.addAction(self.actionPrev_group)
        self.menuView.addAction(self.actionNext_group)
        self.menuView.addAction(self.actionVisible)
        self.menuView.addSeparator()
        self.menuView.addAction(self.actionBit_map)
        self.menuView.addSeparator()
        self.menuView.addAction(self.actionZoom_in)
        self.menuView.addAction(self.actionZoom_out)
        self.menuView.addAction(self.actionFit_window)
        self.menuView.addSeparator()
        self.menuView.addAction(self.actionScene_shot)
        self.menuView.addAction(self.actionWindow_shot)
        self.menuAbout.addAction(self.actionLanguage)
        self.menuAbout.addAction(self.actionShortcut)
        self.menuAbout.addAction(self.actionAbout)
        self.menuTools.addSeparator()
        self.menuTools.addAction(self.actionConverter)
        self.menuTools.addAction(self.actionVideo_to_frames)
        self.menuTools.addAction(self.actionAuto_segment_with_bounding_box)
        self.menuTools.addAction(self.actionAnno_validator)
        self.menuTools.addAction(self.actionProcess_EXIF_tag)
        self.menuEdit.addAction(self.actionSegment_anything_point)
        self.menuEdit.addAction(self.actionSegment_anything_box)
        self.menuEdit.addAction(self.actionPolygon)
        self.menuEdit.addAction(self.actionRepaint)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionVideo_segment)
        self.menuEdit.addAction(self.actionVideo_segment_once)
        self.menuEdit.addAction(self.actionVideo_segment_five_times)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionBackspace)
        self.menuEdit.addAction(self.actionFinish)
        self.menuEdit.addAction(self.actionCancel)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionEdit)
        self.menuEdit.addAction(self.actionDelete)
        self.menuEdit.addAction(self.actionSave)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionTo_top)
        self.menuEdit.addAction(self.actionTo_bottom)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionUnion)
        self.menuEdit.addAction(self.actionSubtract)
        self.menuEdit.addAction(self.actionIntersect)
        self.menuEdit.addAction(self.actionExclude)
        self.menuSAM_model.addAction(self.actionModel_manage)
        self.menuSAM_model.addSeparator()
        self.menuSAM_model.addAction(self.actionRemote_SAM)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuSAM_model.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())
        self.toolBar.addAction(self.actionPrev_image)
        self.toolBar.addAction(self.actionNext_image)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionSegment_anything_point)
        self.toolBar.addAction(self.actionSegment_anything_box)
        self.toolBar.addAction(self.actionPolygon)
        self.toolBar.addAction(self.actionRepaint)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionVideo_segment_once)
        self.toolBar.addAction(self.actionVideo_segment_five_times)
        self.toolBar.addAction(self.actionVideo_segment)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionBackspace)
        self.toolBar.addAction(self.actionFinish)
        self.toolBar.addAction(self.actionCancel)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionEdit)
        self.toolBar.addAction(self.actionCopy)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addAction(self.actionDelete)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionTo_top)
        self.toolBar.addAction(self.actionTo_bottom)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionUnion)
        self.toolBar.addAction(self.actionSubtract)
        self.toolBar.addAction(self.actionIntersect)
        self.toolBar.addAction(self.actionExclude)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionZoom_in)
        self.toolBar.addAction(self.actionZoom_out)
        self.toolBar.addAction(self.actionFit_window)
        self.toolBar.addAction(self.actionBit_map)
        self.toolBar.addAction(self.actionVisible)
        self.toolBar_2.addAction(self.actionModel_manage)
        self.toolBar_2.addAction(self.actionRemote_SAM)
        self.toolBar_2.addAction(self.actionShortcut)
        self.toolBar_2.addAction(self.actionSetting)
        self.toolBar_2.addAction(self.actionLanguage)
        self.toolBar_2.addAction(self.actionAbout)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "ISAT"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuView.setTitle(_translate("MainWindow", "View"))
        self.menuAbout.setTitle(_translate("MainWindow", "Help"))
        self.menuTools.setTitle(_translate("MainWindow", "Tools"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuSAM_model.setTitle(_translate("MainWindow", "SAM"))
        self.toolBar.setWindowTitle(_translate("MainWindow", "toolBar"))
        self.info_dock.setWindowTitle(_translate("MainWindow", "Info"))
        self.annos_dock.setWindowTitle(_translate("MainWindow", "Annos"))
        self.files_dock.setWindowTitle(_translate("MainWindow", "Files"))
        self.categories_dock.setWindowTitle(_translate("MainWindow", "Categories"))
        self.toolBar_2.setWindowTitle(_translate("MainWindow", "toolBar_2"))
        self.actionImages_dir.setText(_translate("MainWindow", "Images dir"))
        self.actionImages_dir.setStatusTip(_translate("MainWindow", "Open images dir."))
        self.actionZoom_in.setText(_translate("MainWindow", "Zoom in"))
        self.actionZoom_in.setStatusTip(_translate("MainWindow", "Zoom in."))
        self.actionZoom_out.setText(_translate("MainWindow", "Zoom out"))
        self.actionZoom_out.setStatusTip(_translate("MainWindow", "Zoom out."))
        self.actionFit_window.setText(_translate("MainWindow", "Fit window"))
        self.actionFit_window.setToolTip(_translate("MainWindow", "Fit window"))
        self.actionFit_window.setStatusTip(_translate("MainWindow", "Fit window."))
        self.actionFit_window.setShortcut(_translate("MainWindow", "F"))
        self.actionSetting.setText(_translate("MainWindow", "Setting"))
        self.actionSetting.setStatusTip(_translate("MainWindow", "Setting."))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionExit.setToolTip(_translate("MainWindow", "Exit"))
        self.actionExit.setStatusTip(_translate("MainWindow", "Exit."))
        self.actionLabel_dir.setText(_translate("MainWindow", "Label dir"))
        self.actionLabel_dir.setStatusTip(_translate("MainWindow", "Open label dir."))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionSave.setStatusTip(_translate("MainWindow", "Save annotation."))
        self.actionSave.setShortcut(_translate("MainWindow", "S"))
        self.actionPrev_image.setText(_translate("MainWindow", "Prev image"))
        self.actionPrev_image.setToolTip(_translate("MainWindow", "Prev image"))
        self.actionPrev_image.setStatusTip(_translate("MainWindow", "Prev image."))
        self.actionPrev_image.setShortcut(_translate("MainWindow", "A"))
        self.actionNext_image.setText(_translate("MainWindow", "Next image"))
        self.actionNext_image.setToolTip(_translate("MainWindow", "Next image"))
        self.actionNext_image.setStatusTip(_translate("MainWindow", "Next image."))
        self.actionNext_image.setShortcut(_translate("MainWindow", "D"))
        self.actionShortcut.setText(_translate("MainWindow", "Shortcut"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionSegment_anything_point.setText(_translate("MainWindow", "Segment anything point"))
        self.actionSegment_anything_point.setToolTip(_translate("MainWindow", "Segment anything point"))
        self.actionSegment_anything_point.setStatusTip(_translate("MainWindow", "Quick annotate using Segment anything."))
        self.actionSegment_anything_point.setShortcut(_translate("MainWindow", "Q"))
        self.actionDelete.setText(_translate("MainWindow", "Delete"))
        self.actionDelete.setToolTip(_translate("MainWindow", "Delete polygon"))
        self.actionDelete.setStatusTip(_translate("MainWindow", "Delete polygon."))
        self.actionDelete.setShortcut(_translate("MainWindow", "Del"))
        self.actionBit_map.setText(_translate("MainWindow", "Bit map"))
        self.actionBit_map.setStatusTip(_translate("MainWindow", "Show instance or segmeent state."))
        self.actionBit_map.setShortcut(_translate("MainWindow", "Space"))
        self.actionEdit.setText(_translate("MainWindow", "Edit"))
        self.actionEdit.setToolTip(_translate("MainWindow", "Edit polygon"))
        self.actionEdit.setStatusTip(_translate("MainWindow", "Edit polygon attribute."))
        self.actionTo_top.setText(_translate("MainWindow", "To top"))
        self.actionTo_top.setToolTip(_translate("MainWindow", "Move polygon to top layer"))
        self.actionTo_top.setStatusTip(_translate("MainWindow", "Move polygon to top layer."))
        self.actionTo_top.setShortcut(_translate("MainWindow", "T"))
        self.actionTo_bottom.setText(_translate("MainWindow", "To bottom"))
        self.actionTo_bottom.setToolTip(_translate("MainWindow", "Move polygon to bottom layer"))
        self.actionTo_bottom.setStatusTip(_translate("MainWindow", "Move polygon to bottom layer."))
        self.actionTo_bottom.setShortcut(_translate("MainWindow", "B"))
        self.actionBackspace.setText(_translate("MainWindow", "Backspace"))
        self.actionBackspace.setToolTip(_translate("MainWindow", "Backspace"))
        self.actionBackspace.setStatusTip(_translate("MainWindow", "Backspace."))
        self.actionBackspace.setShortcut(_translate("MainWindow", "Z"))
        self.actionCancel.setText(_translate("MainWindow", "Cancel"))
        self.actionCancel.setToolTip(_translate("MainWindow", "Annotate canceled"))
        self.actionCancel.setStatusTip(_translate("MainWindow", "Annotate canceled."))
        self.actionCancel.setShortcut(_translate("MainWindow", "Esc"))
        self.actionFinish.setText(_translate("MainWindow", "Finish"))
        self.actionFinish.setToolTip(_translate("MainWindow", "Annotate finished"))
        self.actionFinish.setStatusTip(_translate("MainWindow", "Annotate finished."))
        self.actionFinish.setShortcut(_translate("MainWindow", "E"))
        self.actionPolygon.setText(_translate("MainWindow", "Polygon"))
        self.actionPolygon.setToolTip(_translate("MainWindow", "Draw polygon"))
        self.actionPolygon.setStatusTip(_translate("MainWindow", "Accurately annotate by drawing polygon. "))
        self.actionPolygon.setShortcut(_translate("MainWindow", "C"))
        self.actionVisible.setText(_translate("MainWindow", "Visible"))
        self.actionVisible.setToolTip(_translate("MainWindow", "Visible"))
        self.actionVisible.setStatusTip(_translate("MainWindow", "Visible."))
        self.actionVisible.setShortcut(_translate("MainWindow", "V"))
        self.actionModel_manage.setText(_translate("MainWindow", "Model manage"))
        self.actionModel_manage.setStatusTip(_translate("MainWindow", "Model manage."))
        self.actionModel_manage.setWhatsThis(_translate("MainWindow", "Model manage."))
        self.actionConverter.setText(_translate("MainWindow", "Converter"))
        self.actionAuto_segment_with_bounding_box.setText(_translate("MainWindow", "Auto segment with bounding box"))
        self.actionAnno_validator.setText(_translate("MainWindow", "Annos validator"))
        self.actionCopy.setText(_translate("MainWindow", "Copy"))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actionUnion.setText(_translate("MainWindow", "Union"))
        self.actionUnion.setStatusTip(_translate("MainWindow", "Select two polygons from the canvas and calculate their union. "))
        self.actionUnion.setShortcut(_translate("MainWindow", "Ctrl+A"))
        self.actionSubtract.setText(_translate("MainWindow", "Subtract"))
        self.actionSubtract.setStatusTip(_translate("MainWindow", "Select two polygons from the canvas and calculate their subtract. "))
        self.actionSubtract.setShortcut(_translate("MainWindow", "Ctrl+D"))
        self.actionIntersect.setText(_translate("MainWindow", "Intersect"))
        self.actionIntersect.setStatusTip(_translate("MainWindow", "Select two polygons from the canvas and calculate their intersect. "))
        self.actionIntersect.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actionExclude.setText(_translate("MainWindow", "Exclude"))
        self.actionExclude.setStatusTip(_translate("MainWindow", "Select two polygons from the canvas and calculate their exclude. "))
        self.actionExclude.setShortcut(_translate("MainWindow", "Ctrl+E"))
        self.actionVideo_segment.setText(_translate("MainWindow", "Video segment"))
        self.actionVideo_segment.setStatusTip(_translate("MainWindow", "Video segment full frames.(only support sam2 model)"))
        self.actionVideo_segment_once.setText(_translate("MainWindow", "Video segment once"))
        self.actionVideo_segment_once.setStatusTip(_translate("MainWindow", "Video segment the next frame.(only support sam2 model)"))
        self.actionVideo_segment_five_times.setText(_translate("MainWindow", "Video segment five times"))
        self.actionVideo_segment_five_times.setStatusTip(_translate("MainWindow", "Video segment next five frames.(only support sam2 model)"))
        self.actionVideo_to_frames.setText(_translate("MainWindow", "Video to frames"))
        self.actionSegment_anything_box.setText(_translate("MainWindow", "Segment anything box"))
        self.actionSegment_anything_box.setStatusTip(_translate("MainWindow", "Quick annotate using Segment anything."))
        self.actionSegment_anything_box.setShortcut(_translate("MainWindow", "W"))
        self.actionPrev_group.setText(_translate("MainWindow", "Prev group"))
        self.actionPrev_group.setShortcut(_translate("MainWindow", "`"))
        self.actionNext_group.setText(_translate("MainWindow", "Next group"))
        self.actionNext_group.setShortcut(_translate("MainWindow", "Ctrl+`"))
        self.actionRepaint.setText(_translate("MainWindow", "Repaint"))
        self.actionRepaint.setShortcut(_translate("MainWindow", "R"))
        self.actionScene_shot.setText(_translate("MainWindow", "Scene shot"))
        self.actionScene_shot.setShortcut(_translate("MainWindow", "P"))
        self.actionWindow_shot.setText(_translate("MainWindow", "Window shot"))
        self.actionWindow_shot.setShortcut(_translate("MainWindow", "Ctrl+P"))
        self.actionLanguage.setText(_translate("MainWindow", "Language"))
        self.actionRemote_SAM.setText(_translate("MainWindow", "Remote SAM"))
        self.actionProcess_EXIF_tag.setText(_translate("MainWindow", "Process EXIF tag"))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/media/lg/disk2/PycharmProjects/ISAT_with_segment_anything/ISAT/ui/remote_sam_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(760, 420)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        Dialog.setFont(font)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(Dialog)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.widget = QtWidgets.QWidget(self.tab)
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtWidgets.QLabel(self.widget)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.lineEdit_host = QtWidgets.QLineEdit(self.widget)
        self.lineEdit_host.setObjectName("lineEdit_host")
        self.horizontalLayout.addWidget(self.lineEdit_host)
        self.label_3 = QtWidgets.QLabel(self.widget)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.lineEdit_port = QtWidgets.QLineEdit(self.widget)
        self.lineEdit_port.setObjectName("lineEdit_port")
        self.horizontalLayout.addWidget(self.lineEdit_port)
        self.pushButton_check = QtWidgets.QPushButton(self.widget)
        self.pushButton_check.setObjectName("pushButton_check")
        self.horizontalLayout.addWidget(self.pushButton_check)
        self.verticalLayout_2.addWidget(self.widget)
        self.frame_info = QtWidgets.QFrame(self.tab)
        self.frame_info.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.frame_info.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_info.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_info.setObjectName("frame_info")
        self.gridLayout = QtWidgets.QGridLayout(self.frame_info)
        self.gridLayout.setObjectName("gridLayout")
        self.label_device = QtWidgets.QLabel(self.frame_info)
        self.label_device.setMinimumSize(QtCore.QSize(0, 30))
        self.label_device.setText("")
        self.label_device.setObjectName("label_device")
        self.gridLayout.addWidget(self.label_device, 2, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.frame_info)
        self.label_6.setMinimumSize(QtCore.QSize(0, 30))
        self.label_6.setMaximumSize(QtCore.QSize(80, 16777215))
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 3, 0, 1, 1)
        self.label_name = QtWidgets.QLabel(self.frame_info)
        self.label_name.setMinimumSize(QtCore.QSize(0, 30))
        self.label_name.setText("")
        self.label_name.setObjectName("label_name")
        self.gridLayout.addWidget(self.label_name, 1, 1, 1, 1)
        self.label_dtype = QtWidgets.QLabel(self.frame_info)
        self.label_dtype.setMinimumSize(QtCore.QSize(0, 30))
        self.label_dtype.setText("")
        self.label_dtype.setObjectName("label_dtype")
        self.gridLayout.addWidget(self.label_dtype, 3, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.frame_info)
        self.label_4.setMinimumSize(QtCore.QSize(0, 30))
        self.label_4.setMaximumSize(QtCore.QSize(80, 16777215))
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.frame_info)
        self.label_5.setMinimumSize(QtCore.QSize(0, 30))
        self.label_5.setMaximumSize(QtCore.QSize(80, 16777215))
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 2, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.frame_info)
        self.widget_3 = QtWidgets.QWidget(self.tab)
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.checkBox_use_remote = QtWidgets.QCheckBox(self.widget_3)
        self.checkBox_use_remote.setObjectName("checkBox_use_remote")
        self.horizontalLayout_3.addWidget(self.checkBox_use_remote)
        self.verticalLayout_2.addWidget(self.widget_3)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.textBrowser = QtWidgets.QTextBrowser(self.tab_2)
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout_3.addWidget(self.textBrowser)
        self.tabWidget.addTab(self.tab_2, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.widget_2 = QtWidgets.QWidget(Dialog)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.pushButton_close = QtWidgets.QPushButton(self.widget_2)
        self.pushButton_close.setObjectName("pushButton_close")
        self.horizontalLayout_2.addWidget(self.pushButton_close)
        self.verticalLayout.addWidget(self.widget_2)

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "SAM remote encode server"))
        self.label_2.setText(_translate("Dialog", "Host:"))
        self.label_3.setText(_translate("Dialog", "Port"))
        self.pushButton_check.setText(_translate("Dialog", "Check"))
        self.label_6.setText(_translate("Dialog", "Dtype:"))
        self.label_4.setText(_translate("Dialog", "Model:"))
        self.label_5.setText(_translate("Dialog", "Device:"))
        self.checkBox_use_remote.setText(_translate("Dialog", "Use remote sam encode"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Dialog", "Connect remote server"))
        self.textBrowser.setHtml(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Times New Roman\'; font-size:12pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"># <span style=\" font-weight:600;\">install</span> isat-sam-backend in remote server</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">pip install isat-sam-backend</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"># <span style=\" font-weight:600;\">run</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; font-style:italic;\"># </span>run<span style=\" font-weight:600; font-style:italic;\"> </span>with<span style=\" font-weight:600; font-style:italic;\"> </span>default<span style=\" font-weight:600; font-style:italic;\"> </span>model<span style=\" font-weight:600; font-style:italic;\"> </span>mobile_sam.pt on local machine (default host: 127.0.0.1, default port: 8000)</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">isat-sam-backend run</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"># or run with more arg</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">isat-sam-backend run --checkpoint [model name] --host [ip] --port [port]</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\"># manage remote model</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\"># </span>list<span style=\" font-style:italic;\"> </span>model<span style=\" font-style:italic;\"> </span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">isat-sam-backend model --list</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\"># </span>download<span style=\" font-style:italic;\"> </span>model<span style=\" font-style:italic;\"> </span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">isat-sam-backend model --download [model name]</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; font-style:italic;\"># </span>remove<span style=\" font-weight:600; font-style:italic;\"> </span>model</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">isat-sam-backend model --remove [model name]</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("Dialog", "How to use?"))
        self.pushButton_close.setText(_translate("Dialog", "&Close"))
